4.18-stable review patch.  If anyone has any objections, please let me know.

------------------

From: Hans Holmberg <hans.holmb...@cnexlabs.com>

[ Upstream commit f6352103d2e0ad2d2066725eb19bfdfb8763239b ]

We can't know if a block is closed or not on 1.2 devices, so assume
closed state to make sure that blocks are erased before writing.

Fixes: 32ef9412c114 ("lightnvm: pblk: implement get log report chunk")
Signed-off-by: Hans Holmberg <hans.holmb...@cnexlabs.com>
Signed-off-by: Matias Bjørling <m...@lightnvm.io>
Signed-off-by: Jens Axboe <ax...@kernel.dk>
Signed-off-by: Sasha Levin <alexander.le...@microsoft.com>
Signed-off-by: Greg Kroah-Hartman <gre...@linuxfoundation.org>
---
 drivers/lightnvm/pblk-init.c |    5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

--- a/drivers/lightnvm/pblk-init.c
+++ b/drivers/lightnvm/pblk-init.c
@@ -716,10 +716,11 @@ static int pblk_setup_line_meta_12(struc
 
                /*
                 * In 1.2 spec. chunk state is not persisted by the device. Thus
                 * some of the values are reset each time pblk is instantiated.
                 */
                if (lun_bb_meta[line->id] == NVM_BLK_T_FREE)
-                       chunk->state =  NVM_CHK_ST_FREE;
+                       chunk->state =  NVM_CHK_ST_CLOSED;
                else
                        chunk->state = NVM_CHK_ST_OFFLINE;
 
@@ -716,10 +716,11 @@ static int pblk_setup_line_meta_12(struc
                /*
                 * In 1.2 spec. chunk state is not persisted by the device. Thus
-                * some of the values are reset each time pblk is instantiated.
+                * some of the values are reset each time pblk is instantiated,
+                * so we have to assume that the block is closed.
                 */
                if (lun_bb_meta[line->id] == NVM_BLK_T_FREE)


Reply via email to